@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright: Damien Elmes <anki@ichi2.net>
+# Copyright: Ankitects Pty Ltd and contributors
 # License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
 
 import time, re
 from anki.db import DB
 from anki.importing.noteimp import NoteImporter, ForeignNote, ForeignCard
 from anki.stdmodels import addBasicModel, addClozeModel
-from anki.lang import ngettext
+from anki.lang import ngettext, _
 
 class MnemosyneImporter(NoteImporter):
 
@@ -18,7 +18,8 @@ class MnemosyneImporter(NoteImporter):
         db = DB(self.file)
         ver = db.scalar(
             "select value from global_variables where key='version'")
-        assert ver.startswith('Mnemosyne SQL 1') or ver == "2"
+        if not ver.startswith('Mnemosyne SQL 1') and ver not in ("2","3"):
+            self.log.append(_("File version unknown, trying import anyway."))
         # gather facts into temp objects
         curid = None
         notes = {}
@@ -28,6 +29,7 @@ select _id, id, key, value from facts f, data_for_fact d where
 f._id=d._fact_id"""):
             if id != curid:
                 if note:
+                    # pylint: disable=unsubscriptable-object
                     notes[note['_id']] = note
                 note = {'_id': _id}
                 curid = id
@@ -53,8 +55,12 @@ acq_reps+ret_reps, lapses, card_type_id from cards"""):
                     vocabulary.append(note)
                 elif row[1].startswith("5.1"):
                     cloze[row[0]] = note
+            # check for None to fix issue where import can error out
+            rawTags = row[2]
+            if rawTags is None:
+                rawTags = ""
             # merge tags into note
-            tags = row[2].replace(", ", "\x1f").replace(" ", "_")
+            tags = rawTags.replace(", ", "\x1f").replace(" ", "_")
             tags = tags.replace("\x1f", " ")
             if "tags" not in note:
                 note['tags'] = []
@@ -75,7 +81,7 @@ acq_reps+ret_reps, lapses, card_type_id from cards"""):
             rem = int((next - time.time())/86400)
             c.due = self.col.sched.today+rem
             # get ord
-            m = re.search(".(\d+)$", row[1])
+            m = re.search(r".(\d+)$", row[1])
             ord = int(m.group(1))-1
             if 'cards' not in note:
                 note['cards'] = {}
@@ -97,7 +103,7 @@ acq_reps+ret_reps, lapses, card_type_id from cards"""):
         # \n -> br
         fld = re.sub("\r?\n", "<br>", fld)
         # latex differences
-        fld = re.sub("(?i)<(/?(\$|\$\$|latex))>", "[\\1]", fld)
+        fld = re.sub(r"(?i)<(/?(\$|\$\$|latex))>", "[\\1]", fld)
         # audio differences
         fld = re.sub("<audio src=\"(.+?)\">(</audio>)?", "[sound:\\1]", fld)
         return fld
@@ -158,7 +164,7 @@ acq_reps+ret_reps, lapses, card_type_id from cards"""):
 
     def _addCloze(self, notes):
         data = []
-        notes = notes.values()
+        notes = list(notes.values())
         for orig in notes:
             # create a foreign note object
             n = ForeignNote()
@@ -167,11 +173,12 @@ acq_reps+ret_reps, lapses, card_type_id from cards"""):
             fld = re.sub("\r?\n", "<br>", fld)
             state = dict(n=1)
             def repl(match):
+                # pylint: disable=cell-var-from-loop
                 # replace [...] with cloze refs
                 res = ("{{c%d::%s}}" % (state['n'], match.group(1)))
                 state['n'] += 1
                 return res
-            fld = re.sub("\[(.+?)\]", repl, fld)
+            fld = re.sub(r"\[(.+?)\]", repl, fld)
             fld = self._mungeField(fld)
             n.fields.append(fld)
             n.fields.append("") # extra
